@@ -4,15 +4,13 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/tarpuy/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2020-03-24
+#> date .: 2020-04-29
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
 # packages ----------------------------------------------------------------
 # -------------------------------------------------------------------------
 
-suppressPackageStartupMessages({
-  
 library(inti)
 library(bslib)
 library(metathis)
@@ -22,4 +20,3 @@ library(shinydashboard)
 library(tidyverse)
 library(stringi)
 
-})
