@@ -4,7 +4,7 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/tarpuy/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2022-03-26
+#> date .: 2023-01-21
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -133,7 +133,9 @@ shinyServer(function(input, output, session) {
     
     gs_created <<- gs4_create(
       name = paste("Tarpuy", format(Sys.time(), '%Y-%m-%d  %H:%M'))
-      , sheets = "tarpuy")
+      , sheets = "tarpuy"
+      , locale = "en_US"
+      )
     
     # updt link ---------------------------------------------------------------
 
@@ -181,15 +183,21 @@ shinyServer(function(input, output, session) {
 
     if(input$plex_nfactors == 1) {
 
-      type <- c("crd", "rcbd", "lsd", "lattice")
+      type <- c("crd", "rcbd"
+                # , "lsd", "lattice"
+                )
 
     } else if (input$plex_nfactors == 2) {
 
-      type <- c("crd", "rcbd", "lsd", "split-crd", "split-rcbd", "split-lsd")
+      type <- c("crd", "rcbd"
+                # , "lsd", "split-crd", "split-rcbd", "split-lsd"
+                )
 
     } else if (input$plex_nfactors > 2) {
 
-      type <- c("crd", "rcbd", "lsd")
+      type <- c("crd", "rcbd"
+                # , "lsd"
+                )
 
     }
 
@@ -207,30 +215,31 @@ shinyServer(function(input, output, session) {
   plex <- reactive({
     
     plex <- tarpuy_plex(data = NULL
-                           , idea = input$plex_idea
-                           , goal = input$plex_goal
-                           , hypothesis = input$plex_hypothesis
-                           , rationale = input$plex_rationale
-                           , objectives = input$plex_objectives
-                           , plan = input$plex_plan
-                           , institutions = input$plex_institutions
-                           , researchers = input$plex_researchers
-                           , manager = input$plex_manager
-                           , location = input$plex_location
-                           , altitude = input$plex_altitude
-                           , georeferencing = input$plex_georeferencing
-                           , environment = input$plex_environment
-                           , start = input$plex_dates[1]
-                           , end = input$plex_dates[2]
-                           , about = input$plex_about
-                           , fieldbook = input$plex_fieldbook
-                           , album = input$plex_album
-                           , github = input$plex_github
-                           , nfactor = input$plex_nfactors
-                           , design = input$plex_design
-                           , rep = input$plex_rep
-                           , serie = input$plex_serie
-                           , seed = input$plex_seed
+                         , idea = input$plex_idea
+                         , goal = input$plex_goal
+                         , hypothesis = input$plex_hypothesis
+                         , rationale = input$plex_rationale
+                         , objectives = input$plex_objectives
+                         , plan = input$plex_plan
+                         , institutions = input$plex_institutions
+                         , researchers = input$plex_researchers
+                         , manager = input$plex_manager
+                         , location = input$plex_location
+                         , altitude = input$plex_altitude
+                         , georeferencing = input$plex_georeferencing
+                         , environment = input$plex_environment
+                         , start = input$plex_dates[1]
+                         , end = input$plex_dates[2]
+                         , about = input$plex_about
+                         , fieldbook = input$plex_fieldbook
+                         , album = input$plex_album
+                         , github = input$plex_github
+                         , nfactor = input$plex_nfactors
+                         , design = input$plex_design
+                         , rep = input$plex_rep
+                         , serie = input$plex_serie
+                         , seed = input$plex_seed
+                         , zigzag = input$plex_zigzag
                            )
 
   })
@@ -248,7 +257,7 @@ shinyServer(function(input, output, session) {
 
       plex()$plex %>% sheet_write(ss = gs(), sheet = input$gsheet_info)
 
-    } else { print ("sheet already exist") }
+    } else { print ("sheet already exist: info") }
 
 
 # varlist -----------------------------------------------------------------
@@ -259,7 +268,7 @@ shinyServer(function(input, output, session) {
 
       plex()$variables %>% sheet_write(ss = gs(), sheet = input$gsheet_varlist)
 
-    } else { print ("sheet already exist") }
+    } else { print ("sheet already exist: varlist") }
 
 
 # design ------------------------------------------------------------------
@@ -270,7 +279,7 @@ shinyServer(function(input, output, session) {
 
       plex()$design %>% sheet_write(ss = gs(), sheet = input$gsheet_design)
 
-    } else { print ("sheet already exist") }
+    } else { print ("sheet already exist: design") }
 
 # logbook -----------------------------------------------------------------
 
@@ -279,8 +288,9 @@ shinyServer(function(input, output, session) {
       sheet_add(ss = gs(), sheet = input$plex_logbook)
 
       plex()$logbook %>% sheet_write(ss = gs(), sheet = input$plex_logbook)
-
-    } else { print ("sheet created") }
+      
+      print ("sheet created: logbook")
+    } 
 
 # timetable ---------------------------------------------------------------
 
@@ -289,8 +299,9 @@ shinyServer(function(input, output, session) {
       sheet_add(ss = gs(), sheet = input$plex_timetable)
 
       plex()$timetable %>% sheet_write(ss = gs(), sheet = input$plex_timetable)
-
-    } else { print ("sheet created") }
+      
+      print ("sheet created: timetible")
+    } 
 
 # budget ------------------------------------------------------------------
 
@@ -299,9 +310,19 @@ shinyServer(function(input, output, session) {
       sheet_add(ss = gs(), sheet = input$plex_budget)
 
       plex()$budget %>% sheet_write(ss = gs(), sheet = input$plex_budget)
+      
+      print ("sheet created: budget")
+    } 
+    
 
-    } else { print ("sheet created") }
-
+# -------------------------------------------------------------------------
+    
+    if ( "tarpuy" %in% sheet_names(gs()) ) { 
+      
+      gs() %>% sheet_delete(sheet = "tarpuy")
+      
+    }
+    
   })
 
 # tarpuy design -----------------------------------------------------------
@@ -338,15 +359,21 @@ output$design_type <- renderUI({
 
   if(input$design_nfactors == 1) {
 
-    type <- c("crd", "rcbd", "lsd", "lattice")
+    type <- c("crd", "rcbd"
+              # , "lsd", "lattice"
+              )
 
   } else if (input$design_nfactors == 2) {
 
-    type <- c("crd", "rcbd", "lsd", "split-crd", "split-rcbd", "split-lsd")
+    type <- c("crd", "rcbd"
+              # , "lsd", "split-crd", "split-rcbd", "split-lsd"
+              )
 
   } else if (input$design_nfactors > 2) {
 
-    type <- c("crd", "rcbd", "lsd")
+    type <- c("crd", "rcbd"
+              # , "lsd"
+              )
 
   }
 
@@ -379,7 +406,7 @@ observeEvent(input$export_design, {
   if ( input$gsheet_varlist %in% sheet_names(gs()) ) {
 
     variables <- gs() %>%
-      range_read(input$gsheet_varlist)
+      range_read(input$gsheet_varlist, col_types = "c")
 
   } else { variables <- NULL }
 
@@ -391,31 +418,32 @@ observeEvent(input$export_design, {
         , type = input$design_type
         , rep = input$design_rep
         , serie = input$design_serie
+        , zigzag = as.logical(input$design_zigzag)
         , seed = input$design_seed
-        , barcode = input$design_qr
-      )
+        , fbname = input$design_qr
+      ) 
   
   sheet_export <- input$fb2export %>% gsub("[[:space:]]", "_", .)
   
   if(!is.null(fieldbook)) {
     
-    fbds <- fieldbook %>% tarpuy_varlist(variables)
+    fbds <- tarpuy_traits(fieldbook = fieldbook
+                          , last_factor = NULL
+                          , traits = variables
+                          )
     
     if (input$export_design_overwrite == "no" & !sheet_export %in% sheet_names(gs())) {
       
-      fbds$fieldbook %>%
-        as.data.frame() %>%
+      fbds$fieldbook %>% 
         write_sheet(ss = gs(), sheet = sheet_export)
       
     } else if(input$export_design_overwrite == "yes") {
       
-      fbds$fieldbook %>%
-        as.data.frame() %>%
+      fbds$fieldbook %>% 
         write_sheet(ss = gs(), sheet = sheet_export)
       
     } else {  print ("sheet already exist") }
     
-    
   } else {"Insert factor levels"}
   
 # -------------------------------------------------------------------------
@@ -471,7 +499,7 @@ observeEvent(input$export_design, {
     
     selectizeInput(
       inputId = "sketch_sheets"
-      , label = NULL
+      , label = "Fieldbook"
       , choices = c("choose" = ""
                     , sketch_sheets())
       , multiple = FALSE
@@ -499,14 +527,6 @@ observeEvent(input$export_design, {
                   , width = "100%"
       ),
 
-      selectInput(inputId = "sketch_dim"
-                  , label = "Block factor"
-                  , multiple = FALSE
-                  , choices = c(""
-                                , factors)
-                  , width = "100%"
-      ),
-
       selectInput(inputId = "sketch_fill"
                   , label = "Fill factor"
                   , multiple = FALSE
@@ -516,45 +536,41 @@ observeEvent(input$export_design, {
                   , width = "100%"
       ),
 
-      textInput(inputId = "sketch_dim2"
-                , label = "Block factor (optional)"
-                , value = NA
-                , placeholder = "NcolxNrow"
-                , width = "100%"
-      )
     )
 
   })
+  
+fb_sketch <- reactive({
+  
+  if ( input$sketch_sheets %in% sheet_names(gs()) ) {
+    
+     gs() %>%
+      range_read( input$sketch_sheets )
+  }
+  
+})
 
-  # plot --------------------------------------------------------------------
+# plot --------------------------------------------------------------------
 
   plot_sketch <- reactive({
 
     validate( need( input$fieldbook_url, "LogIn and create or insert a url" ) )
     validate( need( input$sketch_sheets, "Insert your fieldbook" ) )
     validate( need( input$sketch_factor, "Select your design factor") )
-    validate( need( input$sketch_dim, "Select your blocking factor") )
-
-    if ( input$sketch_sheets %in% sheet_names(gs()) ) {
-
-      fb_sketch <- gs() %>%
-        range_read( input$sketch_sheets )
-    }
+    
+# -------------------------------------------------------------------------
 
     if ( input$sketch_xlab == "" | is.null(input$sketch_xlab) ){ sketch_xlab <- NULL } else {sketch_xlab <- input$sketch_xlab}
     if ( input$sketch_ylab == "" | is.null(input$sketch_ylab) ){ sketch_ylab <- NULL } else {sketch_ylab <- input$sketch_ylab}
     if ( input$sketch_glab == "" | is.null(input$sketch_glab) ){ sketch_glab <- NULL } else {sketch_glab <- input$sketch_glab}
 
-    if ( input$sketch_dim2 != "" ) { blocking <- input$sketch_dim2 } else { blocking <- input$sketch_dim }
-
-    plot_sketch <-  tarpuy_plotdesign(data = fb_sketch
-                                , factor = input$sketch_factor
-                                , dim = blocking
-                                , fill = input$sketch_fill
-                                , xlab = sketch_xlab
-                                , ylab = sketch_ylab
-                                , glab = sketch_glab
-    )
+    plot_sketch <-  tarpuy_plotdesign(data = fb_sketch()
+                                      , factor = input$sketch_factor
+                                      , fill = input$sketch_fill
+                                      , xlab = sketch_xlab
+                                      , ylab = sketch_ylab
+                                      , glab = sketch_glab
+                                      )
   })
 
   # -------------------------------------------------------------------------
@@ -651,7 +667,173 @@ observeEvent(input$export_design, {
     }
 
   })
+
+
+
+# connection --------------------------------------------------------------
+# -------------------------------------------------------------------------
+
+output$connection_sheet_fieldbook <- renderUI({
   
+  validate(need(fieldbook_url(), "LogIn and insert a url") )
+  
+  info <- gs4_get(gs())
+  
+  names <- info$sheets$name 
+  
+  selectInput(inputId = "connection_sheet_fieldbook"
+              , label = NULL
+              , choices = c("choose" = ""
+                            , names)
+  )
+})
+
+output$connection_sheet_traits <- renderUI({
+  
+  validate(need(fieldbook_url(), "LogIn and insert a url") )
+  
+  info <- gs4_get(gs())
+  
+  names <- info$sheets$name 
+  
+  selectInput(inputId = "connection_sheet_traits"
+              , label = NULL
+              , choices = c("choose" = ""
+                            , names)
+  )
+})
+
+# -------------------------------------------------------------------------
+
+connection_sheet_preview <- reactive({
+  
+  info <- gs4_get(gs())
+  
+  url <- info$spreadsheet_url
+  
+  id <- if(input$connection_sheet_preview == "Field Book") {
+  
+    info$sheets %>%
+      filter(name %in% input$connection_sheet_fieldbook) %>%
+      pluck("id")
+    
+  } else {
+    
+    info$sheets %>%
+      filter(name %in% input$connection_sheet_traits) %>%
+      pluck("id")
+    
+  }
+  
+  preview <- paste(url, id, sep = "#gid=")
+  
+})
+
+output$connection_sheet_preview <- renderUI({
+  
+  validate( need( input$fieldbook_url, "LogIn and create or insert a url" ) )
+  
+  tags$iframe(src = connection_sheet_preview(),
+              style="height:580px; width:100%; scrolling=no")
+  
+})
+
+# -------------------------------------------------------------------------
+
+traits <- reactive({
+  
+  validate(need(input$connection_sheet_traits, "Need table with traits"))
+  
+  gs() %>%
+    googlesheets4::range_read(sheet = input$connection_sheet_traits
+                              , col_types = "c") 
+  
+})
+
+fieldbook <- reactive({
+  
+  validate(need(input$connection_sheet_fieldbook, "Need field book table"))
+  
+  gs() %>%
+    googlesheets4::range_read(sheet = input$connection_sheet_fieldbook) 
+  
+})
+
+# -------------------------------------------------------------------------
+
+output$connection_fieldbook_lastfactor <- renderUI({
+  
+  validate(need(fieldbook(), "LogIn and insert a url") )
+  
+  names <- fieldbook() %>% names()
+  
+  selectInput(inputId = "connection_fieldbook_lastfactor"
+              , label = "Last Factor"
+              , choices = c("choose" = ""
+                            , names)
+  )
+})
+
+# -------------------------------------------------------------------------
+
+fbapp <- reactive({
+  
+  tarpuy_traits(fieldbook = fieldbook()
+               , last_factor = input$connection_fieldbook_lastfactor
+               , traits = traits()
+               )
+})
+
+# -------------------------------------------------------------------------
+
+output$connection_traits_trt <- downloadHandler(
+  
+  filename = function() {
+    paste('traits-', Sys.Date(), '.trt', sep='')
+  },
+  content = function(con) {
+    fbapp()$traits %>% 
+      write_delim(file = con, delim = ",", quote = "all", na = '""')
+  }
+)
+
+output$connection_fieldbook_csv <- downloadHandler(
+  
+  filename = function() {
+    paste('fieldbook-', Sys.Date(), '.csv', sep='')
+  },
+  content = function(con) {
+    fbapp()$fb %>% 
+      write.csv(file = con)
+  }
+)
+
+# -------------------------------------------------------------------------
+
+output$connection_traits_download <- renderUI({
+  
+  validate(need(input$connection_fieldbook_lastfactor, ""))
+  validate(need(input$connection_sheet_traits, ""))
+
+  downloadButton(outputId = 'connection_traits_trt'
+                 , label =  h6('Traits') 
+                 , icon = icon("download", "fa-2x") 
+  )
+  
+})
+
+output$connection_fieldbook_download <- renderUI({
+  
+  validate(need(input$connection_fieldbook_lastfactor, ""))
+  validate(need(input$connection_sheet_traits, ""))
+
+  downloadButton(outputId = 'connection_fieldbook_csv'
+                 , label = h6('FieldBook')
+                 , icon = icon("download", "fa-2x")
+  )
+  
+})
+
 # end app -----------------------------------------------------------------
 # -------------------------------------------------------------------------
 
